# Human Bioheat Model For Extremely Cold Exposures


*the model is improved from Zhuqiang Hu 's model*
## Requirement

* numpy
* pandas
* scipy
* matplotlib
* solartotr

## Installation

    pip install humancoldmodel

## Usage

